@@ -3,7 +3,7 @@ use Moose::Role;
 use Moose::Util::TypeConstraints;
 use Carp;
 
-our $VERSION = '0.1';
+our $VERSION = '1.03';
 
 #-----------------------------------------------------------------------------
 #------------------------------- Attributes ----------------------------------
@@ -115,7 +115,7 @@ sub pragmaRequest {
 
 #-----------------------------------------------------------------------------
 
-sub effectHash {
+sub tidyVariantEffect {
     my ( $self, $line ) = @_;
   
     if ( ! $line ) { return }
@@ -134,8 +134,8 @@ sub effectHash {
 
         $variant{ $type[0] } = {
             index        => $type[1],
-            feature      => $type[2],
-            feature_type => $typeList,
+            feature_type      => $type[2],
+            feature_id => $typeList,
 	    
         };
     }
